Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(46)

Unified Diff: editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/internal/cache/AnalysisCache.java

Issue 24481002: New analyzer_experimental snapshot. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/internal/cache/AnalysisCache.java
diff --git a/editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/internal/cache/AnalysisCache.java b/editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/internal/cache/AnalysisCache.java
index 6c943194d171b27147d746c940d87a3e578bea21..904488b7d2ee703c2ac25e292e280a2a68758a78 100644
--- a/editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/internal/cache/AnalysisCache.java
+++ b/editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/internal/cache/AnalysisCache.java
@@ -17,9 +17,9 @@ import com.google.dart.engine.AnalysisEngine;
import com.google.dart.engine.source.Source;
import java.util.ArrayList;
+import java.util.Collection;
import java.util.HashMap;
import java.util.Map.Entry;
-import java.util.Set;
/**
* Instances of the class {@code AnalysisCache} implement an LRU cache of information related to
@@ -105,12 +105,12 @@ public class AnalysisCache {
}
/**
* Return a set containing all of the map entries mapping sources to cache entries. Clients should
* not modify the returned set.
*
* @return a set containing all of the map entries mapping sources to cache entries
*/
- public Set<Entry<Source, SourceEntry>> entrySet() {
+ public Collection<Entry<Source, SourceEntry>> entrySet() {
return sourceMap.entrySet();
}
@@ -105,12 +105,12 @@ public class AnalysisCache {
}
/**
- * Return a set containing all of the map entries mapping sources to cache entries. Clients should
- * not modify the returned set.
+ * Return a collection containing all of the map entries mapping sources to cache entries. Clients
+ * should not modify the returned collection.
*
@@ -105,12 +105,12 @@ public class AnalysisCache {
*
- * @return a set containing all of the map entries mapping sources to cache entries
+ * @return a collection containing all of the map entries mapping sources to cache entries
*/

Powered by Google App Engine
This is Rietveld 408576698